# Spatial Access

This package provides classical and novel measures of spatial accessibility to services.

For full documentation, see [access.readthedocs.io](https://access.readthedocs.io/en/latest/).

